@@ -9,19 +9,23 @@
 #' @param group the variable used as the second grouping variable on x axis.
 #' @param xlab a character string to give x axis label.
 #' @param ylab a character string to give y axis label.
-#' @param label.size the font size of labels shown above the bars.   
-#' @param vjust the distance of labels from the top border of each bar. 
+#' @param label.size the font size of legend labels shown above the bars.   
+#' @param vjust the vertical distance of labels from the top border of each bar. 
+#' @param hjust the horizontal distance of labels from the top border of each bar. 
 #' @param pattern.type a list of objects returned by \code{readPNG} and \code{readJPEG} used to fill the bars. 
 #' @param frame.color the color of the borders of bars.
 #' @param frame.size a numeric value, the line size for the borders of bars.
 #' @param legend.type if legend.type='h', the layout of legends is horizontal;
 #'  if legend.type='v', the layout of legends is vertical. 
 #' @param legend.h a numeric value to change the height of legend boxes.
+#' @param legend.x.pos a numeric value to change the position of legends on x axis.
 #' @param legend.y.pos a numeric value to change the position of legends on y axis.
-#' @param legend.pixel a numeric value to change the pixel of legends. 
+#' @param legend.w a numeric value to change the width of legends. 
+#' @param legend.pixel a numeric value to change the pixel of legend boxes
+#' @param bar.width a numeric value to change the width of the bars.  
 #' @return  A ggplot object.
 #'
-#' @details \code{imagebar} function offers flexible ways in doing bar charts.
+#' @details \code{imagebar} function offers flexible ways of doing bar charts.
 #'   
 #' @author Chunqiao Luo (chunqiaoluo@gmail.com)
 #'
@@ -29,13 +33,13 @@
 #'
 #' @example vignettes/example-imagebar.R
 
-imagebar<-function(data,x, y, group=NULL, xlab='', ylab='', label.size=3.5, vjust=-1, 
+imagebar<-function(data,x, y, group=NULL, xlab='', ylab='', label.size=3.5, vjust=-1, hjust=-1,
                    pattern.type, frame.color='black',frame.size=1,
-                   legend.type='h', legend.h=6, legend.y.pos=0.5, legend.pixel=5){
+                   legend.type='h', legend.h=6, legend.x.pos=1.1, legend.y.pos=0.49, legend.w=0.2, legend.pixel=0.3, bar.width=0.9){
 
   if(is.null(group)){
     
-    bplot <- ggplot(data, aes(x, y)) + geom_bar(stat="identity")+geom_text(aes(label=y)) 
+    bplot <- ggplot(data, aes(x, y)) + geom_bar(stat="identity", width = bar.width)+geom_text(aes(label=y)) 
     
     #Box Data
     gdata<-ggplot_build(bplot)$data[[1]]
@@ -65,12 +69,12 @@ imagebar<-function(data,x, y, group=NULL, xlab='', ylab='', label.size=3.5, vjus
     #Text Data
     ldata<-ggplot_build(bplot)$data[[2]]
     
-    g<- ggplot()+ mapply(function(i) geom_raster(data = picdata[[i]], aes(x = X, y = Y, fill = rgb(r,g, b,a))),1:dim(gdata)[1])+scale_fill_identity()+geom_rect(aes(xmin=gdata[,"xmin"],xmax=gdata[,"xmax"],ymin=0,ymax=gdata[,"ymax"]), color=frame.color,size=frame.size, fill=NA)
-    g+ theme_bw()+xlab(xlab)+ylab(ylab)+ scale_x_continuous(breaks=seq(1:length(levels(x))), labels=levels(x))+geom_text(data=ldata, aes(x, y, label=label), vjust=vjust, size=label.size)
+    g<- ggplot()+mapply(function(i) geom_tile(data = picdata[[i]], aes(x = X, y = Y, fill = rgb(r,g, b,a))),1:dim(gdata)[1])+scale_fill_identity()+geom_rect(aes(xmin=gdata[,"xmin"],xmax=gdata[,"xmax"],ymin=0,ymax=gdata[,"ymax"]), color=frame.color,size=frame.size, fill=NA)
+    g+ theme_bw()+xlab(xlab)+ylab(ylab)+ scale_x_continuous(breaks=seq(1:length(levels(x))), labels=levels(x))+geom_text(data=ldata, aes(x, y, label=label), vjust=vjust, hjust=hjust, size=label.size)
     
   }else{
     
-    bplot <- ggplot(data, aes(x, y, fill=group)) + geom_bar(stat="identity", position=position_dodge()) +geom_text(aes(label=y),position=position_dodge(width=0.9)) 
+    bplot <- ggplot(data, aes(x, y, fill=group)) + geom_bar(stat="identity", position=position_dodge(), width = bar.width) +geom_text(aes(label=y),position=position_dodge(width=0.9)) 
     gdata<-ggplot_build(bplot)$data[[1]]
     gdata<-gdata[order(gdata$group),]
     boxmatrix<-list()
@@ -121,23 +125,23 @@ imagebar<-function(data,x, y, group=NULL, xlab='', ylab='', label.size=3.5, vjus
         legend.frame.ymin[i]<-legend.y[i+1]
       }
       legend.label.y<-legend.y.pos*(legend.frame.ymin+legend.frame.ymax)
-      legend.label.x<-legend.frame.xmax+0.2*(gdata[1,"xmax"]-xmin)
+      legend.label.x<-legend.x.pos*legend.w
       
     }
     
     if(legend.type=='h'){
       legend.y<-c(ymax+0.1*ymax, ymax+(0.1+0.01*legend.h)*ymax)
-      unit.x<-((xmax-xmin)-(gdata[1,"xmax"]-xmin)*length(pattern.type))/length(pattern.type)
+      legend.x.s<-seq(from =xmin, to =0.67* xmax, length.out=length(pattern.type))
       legend.frame.xmin<-vector(mode="numeric", length=length(pattern.type))
       legend.frame.xmax<-vector(mode="numeric", length=length(pattern.type))
       legend.frame.ymin<-vector(mode="numeric", length=length(pattern.type))
       legend.frame.ymax<-vector(mode="numeric", length=length(pattern.type))
       for (i in 1:length(pattern.type)){
-        legendbox[[i]]<-matrix(c(xmin+(i-1)*(gdata[1,"xmax"]-xmin+unit.x), legend.y[1],
-                                 gdata[1,"xmax"]+(i-1)*(gdata[1,"xmax"]-xmin+unit.x), legend.y[1],
-                                 gdata[1,"xmax"]+(i-1)*(gdata[1,"xmax"]-xmin+unit.x),legend.y[2],
-                                 xmin+(i-1)*(gdata[1,"xmax"]-xmin+unit.x),legend.y[2],
-                                 xmin+(i-1)*(gdata[1,"xmax"]-xmin+unit.x),legend.y[1]),
+        legendbox[[i]]<-matrix(c(legend.x.s[i], legend.y[1],
+                                 legend.x.s[i]+legend.w, legend.y[1],
+                                 legend.x.s[i]+legend.w,legend.y[2],
+                                 legend.x.s[i],legend.y[2],
+                                 legend.x.s[i],legend.y[1]),
                                nrow=5, 
                                ncol=2, byrow=T)
         pattern<-pattern.type[[i]]
@@ -148,17 +152,16 @@ imagebar<-function(data,x, y, group=NULL, xlab='', ylab='', label.size=3.5, vjus
         legend.frame.ymax[i]<-legendbox[[i]][3,2]
         legend.frame.ymin[i]<-legendbox[[i]][1,2]
       }
-      legend.label.y<-legend.y.pos*(legend.frame.ymin+legend.frame.ymax)
-      legend.label.x<-legend.frame.xmax+0.1*(gdata[1,"xmax"]-xmin) 
+      legend.label.y<-(legend.frame.ymin+legend.frame.ymax)*legend.y.pos
+      legend.label.x<-legend.x.s+legend.x.pos*legend.w
     }
     
     #Text Data
     ldata<-ggplot_build(bplot)$data[[2]]
-    frame.color2<-rep(frame.color,time=length(unique(x)))
     
     X<-Y<-r<-g<-b<-a<-pos<-label<-NULL
-    g<- ggplot()+ mapply(function(i) geom_raster(data = picdata[[i]], aes(x = X, y = Y, fill = rgb(r,g, b,a))),1:dim(gdata)[1])+scale_fill_identity()+geom_rect(aes(xmin=gdata[,"xmin"],xmax=gdata[,"xmax"],ymin=0,ymax=gdata[,"ymax"]), color=frame.color2,size=frame.size, fill=NA)
-    g<-g+ theme_bw()+xlab(xlab)+ylab(ylab)+ scale_x_continuous(breaks=seq(1:length(levels(x))), labels=levels(x))+geom_text(data=ldata, aes(x, y, label=label), vjust=vjust, size=label.size)
-    g+ mapply(function(i) geom_raster(data = legenddata[[i]], aes(x = X, y = Y, fill = rgb(r,g, b,a))),1:length(pattern.type))+geom_rect(aes(xmin=legend.frame.xmin,xmax=legend.frame.xmax,ymin=legend.frame.ymin,ymax=legend.frame.ymax), color=frame.color,size=frame.size, fill=NA)+geom_text(aes(x=legend.label.x, y=legend.label.y, label=levels(group), hjust=0, vjust=0), size=label.size)
+    g<- ggplot()+ mapply(function(i) geom_tile(data = picdata[[i]], aes(x = X, y = Y, fill = rgb(r,g, b,a))),1:dim(gdata)[1])+scale_fill_identity()+geom_rect(aes(xmin=gdata[,"xmin"],xmax=gdata[,"xmax"],ymin=0,ymax=gdata[,"ymax"]), color=frame.color,size=frame.size, fill=NA)
+    g<-g+ theme_bw()+xlab(xlab)+ylab(ylab)+ scale_x_continuous(breaks=seq(1:length(levels(x))), labels=levels(x))+geom_text(data=ldata, aes(x, y, label=label), vjust=vjust,hjust=hjust, size=label.size)
+    g+ mapply(function(i) geom_tile(data = legenddata[[i]], aes(x = X, y = Y, fill = rgb(r,g, b,a))),1:length(pattern.type))+geom_rect(aes(xmin=legend.frame.xmin,xmax=legend.frame.xmax,ymin=legend.frame.ymin,ymax=legend.frame.ymax), color=frame.color,size=frame.size, fill=NA)+geom_text(aes(x=legend.label.x, y=legend.label.y, label=levels(group), hjust=0, vjust=0), size=label.size)
   }
   }
