@@ -10,7 +10,7 @@
 #' @param group the variable used as the second grouping variable on x axis.
 #' @param xlab a character string to give x axis label.
 #' @param ylab a character string to give y axis label.
-#' @param legend.label.size the font size of legend labels.   
+#' @param label.size the font size of legend labels.   
 #' @param pattern.type a list of objects returned by \code{readPNG} and \code{readJPEG} used to fill boxplots. 
 #' @param frame.color the color for the borders of boxplots.
 #' @param linetype the linetype for the borders of boxplots.
@@ -22,11 +22,11 @@
 #' @param legend.h a numeric value to fine-tune the width of legend boxes on y axis. 
 #' @param legend.x.pos a numeric value to change the position of legend text on x axis.
 #' @param legend.y.pos a numeric value to change the position of legend text on y axis.
-#' @param legend.pixel a numeric value to change the pixel of legend boxes.  
-#' @param legend.ratio1 a numeric value to fine-tune the position of legend boxes on y axis.
+#' @param legend.w a numeric value to change the width of legends. 
+#' @param legend.pixel a numeric value to change the pixel of legend boxes. 
 #' @return  A ggplot object.
 #'
-#' @details \code{imageboxplot} function offers flexible ways in doing boxplots.
+#' @details \code{imageboxplot} function offers flexible ways of doing boxplots.
 #'   
 #' @author Chunqiao Luo (chunqiaoluo@gmail.com)
 #'
@@ -34,8 +34,8 @@
 #'
 #' @example vignettes/example-imageboxplot.R
 
-imageboxplot<-function(data,x, y, group=NULL , xlab='', ylab='', pattern.type, frame.color='black',linetype='solid',frame.size=1, outlier.shape=21, outlier.color='black', outlier.size=1,
-                       legend.type='h', legend.h=6, legend.x.pos=0.5, legend.y.pos=0.5, legend.pixel=0.3, legend.label.size=3, legend.ratio1=0.1){
+imageboxplot<-function(data,x, y, group=NULL , xlab='', ylab='',label.size=3.5,  pattern.type, frame.color='black', linetype='solid',
+                       frame.size=1, outlier.shape=21, outlier.color='black', outlier.size=1,legend.type='h', legend.h=6, legend.x.pos=1.1, legend.y.pos=0.49, legend.w=0.2, legend.pixel=0.3){
 
   if(is.null(group)){
     
@@ -71,7 +71,7 @@ imageboxplot<-function(data,x, y, group=NULL , xlab='', ylab='', pattern.type, f
     count<-sapply(outliers, length)
     odata=data.frame(y=unlist(outliers), x=rep(gdata[, 'x'], count))
     
-    g<- ggplot()+ mapply(function(i) geom_raster(data = picdata[[i]], aes(x = X, y = Y, fill = rgb(r,g, b,a))),1:dim(gdata)[1])+scale_fill_identity()+geom_rect(aes(xmin=gdata[,"xmin"],xmax=gdata[,"xmax"],ymin=gdata[,"lower"],ymax=gdata[,"upper"]), color=frame.color,size=frame.size, fill=NA)
+    g<- ggplot()+ mapply(function(i) geom_tile(data = picdata[[i]], aes(x = X, y = Y, fill = rgb(r,g, b,a))),1:dim(gdata)[1])+scale_fill_identity()+geom_rect(aes(xmin=gdata[,"xmin"],xmax=gdata[,"xmax"],ymin=gdata[,"lower"],ymax=gdata[,"upper"]), color=frame.color,size=frame.size, fill=NA)
     g<-g+geom_segment(aes(x=gdata[,"xmin"],y=gdata[,"middle"], xend=gdata[,"xmax"], yend=gdata[,"middle"]), color=frame.color,size=frame.size)+geom_segment(aes(x=gdata[,"xmiddel"],y=gdata[,"ymin"], xend=gdata[,"xmiddel"], yend=gdata[,"lower"]), color=frame.color, linetype=linetype,size=frame.size)+geom_segment(aes(x=gdata[,"xmiddel"],y=gdata[,"ymax"], xend=gdata[,"xmiddel"], yend=gdata[,"upper"]), color=frame.color, linetype=linetype,size=frame.size)
     g<-g+geom_segment(aes(x=gdata[,"xmiddel"]-gdata[, "xrange"],y=gdata[,"ymax"], xend=gdata[,"xmiddel"]+gdata[, "xrange"], yend=gdata[,"ymax"]), color=frame.color,size=frame.size)+geom_segment(aes(x=gdata[,"xmiddel"]-gdata[, "xrange"],y=gdata[,"ymin"], xend=gdata[,"xmiddel"]+gdata[, "xrange"], yend=gdata[,"ymin"]), color=frame.color,size=frame.size)
     g+ scale_x_continuous(breaks=gdata[,'group'], labels=levels(x))+ theme_bw()+xlab(xlab)+ylab(ylab)+geom_point(data=odata, aes(x, y), shape=outlier.shape, color=outlier.color, size=outlier.size)
@@ -107,7 +107,7 @@ imageboxplot<-function(data,x, y, group=NULL , xlab='', ylab='', pattern.type, f
     legenddata<-list()
     ymax2<-max(gdata[, c('ymax_final')])
     if(legend.type=='v'){
-      legend.y<-seq(from =ymax2+(legend.ratio1+0.05*legend.h)*ymax2, to = ymax2+legend.ratio1*ymax2, length.out=length(pattern.type)+1)
+      legend.y<-seq(from =ymax+(0.1+0.05*legend.h)*ymax, to = ymax+0.1*ymax, length.out=length(pattern.type)+1)
       legend.x<-seq(from = xmin, to = xmin+ 0.5*(gdata[1,"xmax"]-xmin), length.out=2)
       legend.frame.xmin<-vector(mode="numeric", length=length(pattern.type))
       legend.frame.xmax<-vector(mode="numeric", length=length(pattern.type))
@@ -130,23 +130,22 @@ imageboxplot<-function(data,x, y, group=NULL , xlab='', ylab='', pattern.type, f
         legend.frame.ymin[i]<-legend.y[i+1]
       }
       legend.label.y<-legend.y.pos*(legend.frame.ymin+legend.frame.ymax)
-      legend.label.x<-legend.frame.xmax+legend.x.pos*(gdata[1,"xmax"]-xmin)
-      
+      legend.label.x<-legend.x.pos*legend.w
     }
     
     if(legend.type=='h'){
-      legend.y<-c(ymax2+legend.ratio1*ymax2, ymax2+(legend.ratio1+0.01*legend.h)*ymax2)
-      unit.x<-((xmax-xmin)-(gdata[1,"xmax"]-xmin)*length(pattern.type))/length(pattern.type)
+      legend.y<-c(ymax+0.1*ymax, ymax+(0.1+0.01*legend.h)*ymax)
+      legend.x.s<-seq(from =xmin, to =0.67* xmax, length.out=length(pattern.type))
       legend.frame.xmin<-vector(mode="numeric", length=length(pattern.type))
       legend.frame.xmax<-vector(mode="numeric", length=length(pattern.type))
       legend.frame.ymin<-vector(mode="numeric", length=length(pattern.type))
       legend.frame.ymax<-vector(mode="numeric", length=length(pattern.type))
       for (i in 1:length(pattern.type)){
-        legendbox[[i]]<-matrix(c(xmin+(i-1)*(gdata[1,"xmax"]-xmin+unit.x), legend.y[1],
-                                 gdata[1,"xmax"]+(i-1)*(gdata[1,"xmax"]-xmin+unit.x), legend.y[1],
-                                 gdata[1,"xmax"]+(i-1)*(gdata[1,"xmax"]-xmin+unit.x),legend.y[2],
-                                 xmin+(i-1)*(gdata[1,"xmax"]-xmin+unit.x),legend.y[2],
-                                 xmin+(i-1)*(gdata[1,"xmax"]-xmin+unit.x),legend.y[1]),
+        legendbox[[i]]<-matrix(c(legend.x.s[i], legend.y[1],
+                                 legend.x.s[i]+legend.w, legend.y[1],
+                                 legend.x.s[i]+legend.w,legend.y[2],
+                                 legend.x.s[i],legend.y[2],
+                                 legend.x.s[i],legend.y[1]),
                                nrow=5, 
                                ncol=2, byrow=T)
         pattern<-pattern.type[[i]]
@@ -157,8 +156,8 @@ imageboxplot<-function(data,x, y, group=NULL , xlab='', ylab='', pattern.type, f
         legend.frame.ymax[i]<-legendbox[[i]][3,2]
         legend.frame.ymin[i]<-legendbox[[i]][1,2]
       }
-      legend.label.y<-legend.y.pos*(legend.frame.ymin+legend.frame.ymax)
-      legend.label.x<-legend.frame.xmax+legend.x.pos*(gdata[1,"xmax"]-xmin) 
+      legend.label.y<-(legend.frame.ymin+legend.frame.ymax)*legend.y.pos
+      legend.label.x<-legend.x.s+legend.x.pos*legend.w
     }
     
 
@@ -172,12 +171,12 @@ imageboxplot<-function(data,x, y, group=NULL , xlab='', ylab='', pattern.type, f
     
     X<-Y<-r<-g<-b<-a<-pos<-NULL
     
-    g<- ggplot()+ mapply(function(i) geom_raster(data = picdata[[i]], aes(x = X, y = Y, fill = rgb(r,g, b,a))),1:dim(gdata)[1])+scale_fill_identity()+geom_rect(aes(xmin=gdata[,"xmin"],xmax=gdata[,"xmax"],ymin=gdata[,"lower"],ymax=gdata[,"upper"]), color=frame.color2,size=frame.size, fill=NA)
+    g<- ggplot()+ mapply(function(i) geom_tile(data = picdata[[i]], aes(x = X, y = Y, fill = rgb(r,g, b,a))),1:dim(gdata)[1])+scale_fill_identity()+geom_rect(aes(xmin=gdata[,"xmin"],xmax=gdata[,"xmax"],ymin=gdata[,"lower"],ymax=gdata[,"upper"]), color=frame.color2,size=frame.size, fill=NA)
     g<-g+geom_segment(aes(x=gdata[,"xmin"],y=gdata[,"middle"], xend=gdata[,"xmax"], yend=gdata[,"middle"]), color=frame.color2,size=frame.size)+geom_segment(aes(x=gdata[,"xmiddel"],y=gdata[,"ymin"], xend=gdata[,"xmiddel"], yend=gdata[,"lower"]), color=frame.color2, linetype=linetype2,size=frame.size)+geom_segment(aes(x=gdata[,"xmiddel"],y=gdata[,"ymax"], xend=gdata[,"xmiddel"], yend=gdata[,"upper"]), color=frame.color2, linetype=linetype2,size=frame.size)
     g<-g+geom_segment(aes(x=gdata[,"xmiddel"]-gdata[, "xrange"],y=gdata[,"ymax"], xend=gdata[,"xmiddel"]+gdata[, "xrange"], yend=gdata[,"ymax"]), color=frame.color2,size=frame.size)+geom_segment(aes(x=gdata[,"xmiddel"]-gdata[, "xrange"],y=gdata[,"ymin"], xend=gdata[,"xmiddel"]+gdata[, "xrange"], yend=gdata[,"ymin"]), color=frame.color2,size=frame.size)
     g<-g+ theme_bw()+xlab(xlab)+ylab(ylab)+ scale_x_continuous(breaks=seq(1:length(levels(x))), labels=levels(x))+geom_point(data=odata, aes(x, y), shape=outlier.shape, color=outlier.color, size=outlier.size)
-    g<-g+mapply(function(i) geom_raster(data = legenddata[[i]], aes(x = X, y = Y, fill = rgb(r,g, b,a))),1:length(pattern.type))+geom_rect(aes(xmin=legend.frame.xmin,xmax=legend.frame.xmax,ymin=legend.frame.ymin,ymax=legend.frame.ymax), color=frame.color,size=frame.size, fill=NA)
-    g+geom_text(aes(x=legend.label.x, y=legend.label.y, label=levels(group), hjust=0, vjust=0), size=legend.label.size)
+    g<-g+mapply(function(i) geom_tile(data = legenddata[[i]], aes(x = X, y = Y, fill = rgb(r,g, b,a))),1:length(pattern.type))+geom_rect(aes(xmin=legend.frame.xmin,xmax=legend.frame.xmax,ymin=legend.frame.ymin,ymax=legend.frame.ymax), color=frame.color,size=frame.size, fill=NA)
+    g+geom_text(aes(x=legend.label.x, y=legend.label.y, label=levels(group), hjust=0, vjust=0), size=label.size)
     
   }
     
